/** ###################################################################
**     THIS BEAN MODULE IS GENERATED BY THE TOOL. DO NOT MODIFY IT.
**     Filename  : LCD_D4.C
**     Project   : pp
**     Processor : 56F801FA80
**     Beantype  : PWM
**     Version   : Bean 02.112, Driver 01.15, CPU db: 2.71.091
**     Compiler  : Metrowerks DSP C Compiler
**     Date/Time : 08/04/2008, 07:53 a.m.
**     Abstract  :
**         This bean implements a pulse-width modulation generator
**         that generates signal with variable duty and fixed cycle. 
**     Settings  :
**         Used output pin             : 
**             ----------------------------------------------------
**                Number (on package)  |    Name
**             ----------------------------------------------------
**                       40            |  PWMA0
**             ----------------------------------------------------
**
**         Timer name                  : PWM_A [15-bit] 
**         Counter                     : PWMA_PMCNT [3588]
**         Mode register               : PWMA_PMCTL [3584]
**         Run register                : PWMA_PMCTL [3584]
**         Prescaler                   : PWMA_PMCTL [3584]
**         Compare register            : PWMA_PWMVAL0 [3590]
**         Flip-flop register          : PWMA_PMCFG [3599]
**
**         User handling procedure     : not specified
**
**
**         Initialization:
**              Output level           : high
**              Timer                  : Enabled
**              Event                  : Enabled
**         High speed mode
**             Prescaler               : divide-by-1
**             Clock                   : 10000000 Hz
**           Initial value of            period     pulse width
**             Xtal ticks              : 16000      8000
**             microseconds            : 2000       1000
**             milliseconds            : 2          1
**             seconds (real)          : 0.0020000  0.0010000
**
**     Contents  :
**         SetRatio16 - byte LCD_D4_SetRatio16(word Ratio);
**         SetDutyUS  - byte LCD_D4_SetDutyUS(word Time);
**         SetDutyMS  - byte LCD_D4_SetDutyMS(word Time);
**         SetValue   - byte LCD_D4_SetValue(void);
**         ClrValue   - byte LCD_D4_ClrValue(void);
**
**     (c) Copyright UNIS, spol. s r.o. 1997-2006
**     UNIS, spol. s r.o.
**     Jundrovska 33
**     624 00 Brno
**     Czech Republic
**     http      : www.processorexpert.com
**     mail      : info@processorexpert.com
** ###################################################################*/


/* MODULE LCD_D4. */

#include "LCD_D4.h"

static bool EnUser;                    /* Enable/Disable device by user */
static word RatioStore;                /* Ratio of L-level to H-level */

/* Internal method prototypes */
static void SetRatio(void);

#define SetPV(Val) setRegBitGroup(PWMA_PMCTL,PRSC,(Val))

/*
** ===================================================================
**     Method      :  SetRatio (bean PWM)
**
**     Description :
**         Calculates and sets new duty ratio. The method is called 
**         automatically as a part of several internal methods.
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
static void SetRatio(void)
{
  setReg(PWMA_PWMVAL0,((getReg(PWMA_PWMCM)+1) * (dword)RatioStore) >> 16); /* Calculate new value according to the given ratio */
  setRegBit(PWMA_PMCTL,LDOK);          /* Load counter and modulo registers into buffers */
}
/*
** ===================================================================
**     Method      :  LCD_D4_SetRatio16 (bean PWM)
**
**     Description :
**         This method sets a new duty-cycle ratio.
**     Parameters  :
**         NAME       - DESCRIPTION
**         Ratio      - Ratio is expressed as an 16-bit unsigned integer
**                      number. 0 - 65535 value is proportional
**                      to ratio 0 - 100%
**         Note: Calculated duty depends on the timer possibilities
**               and on the selected period.
**     Returns     :
**         ---        - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
** ===================================================================
*/
byte LCD_D4_SetRatio16(word Ratio)
{
  RatioStore = Ratio;                  /* Store new value of the ratio */
  SetRatio();                          /* Calculate and set up new appropriate duty value */
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  LCD_D4_SetDutyUS (bean PWM)
**
**     Description :
**         This method sets the new duty value of the output signal.
**         The duty is expressed in microseconds as a 16-bit
**         unsigned integer number.
**     Parameters  :
**         NAME            - DESCRIPTION
**         Time            - Duty to set [in microseconds]
**                      (0 to 2000 us in high speed mode)
**     Returns     :
**         ---             - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
**                           ERR_MATH - Overflow during evaluation
**                           ERR_RANGE - Parameter out of range
** ===================================================================
*/
byte LCD_D4_SetDutyUS(word Time)
{
  dlong rtval;                         /* Result of two 32-bit numbers multiplication */

  if (Time >= (word)2000U) {           /* Is the given value out of range? */
    return ERR_RANGE;                  /* If yes then error */
  }
  PE_Timer_LngMul((dword)Time,549755814UL,&rtval); /* Multiply given value and high speed CPU mode coefficient */
  if (PE_Timer_LngHi3(rtval[0],rtval[1],&RatioStore)) { /* Is the result greater or equal than 65536 ? */
    RatioStore = (word)65535U;         /* If yes then use maximal possible value */
  }
  SetRatio();                          /* Calculate and set up new appropriate duty value */
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  LCD_D4_SetDutyMS (bean PWM)
**
**     Description :
**         This method sets the new duty value of the output signal.
**         The duty is expressed in milliseconds as a 16-bit
**         unsigned integer number.
**     Parameters  :
**         NAME            - DESCRIPTION
**         Time            - Duty to set [in milliseconds]
**                      (0 to 2 ms in high speed mode)
**     Returns     :
**         ---             - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
**                           ERR_MATH - Overflow during evaluation
**                           ERR_RANGE - Parameter out of range
** ===================================================================
*/
byte LCD_D4_SetDutyMS(word Time)
{
  dlong rtval;                         /* Result of two 32-bit numbers multiplication */

  if (Time >= (word)2U) {              /* Is the given value out of range? */
    return ERR_RANGE;                  /* If yes then error */
  }
  PE_Timer_LngMul((dword)Time,2147483648UL,&rtval); /* Multiply given value and high speed CPU mode coefficient */
  if (PE_Timer_LngHi2(rtval[0],rtval[1],&RatioStore)) { /* Is the result greater or equal than 65536 ? */
    RatioStore = (word)65535U;         /* If yes then use maximal possible value */
  }
  SetRatio();                          /* Calculate and set up new appropriate duty value */
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  LCD_D4_SetValue (bean PWM)
**
**     Description :
**         This method sets (sets to "1" = "High") timer flip-flop
**         output signal level. It allow user to directly set the
**         output pin value (=flip-flop state), and can set the
**         signal polarity. This method only works when the timer is
**         disabled (Disable) otherwise it returns the error code.
**         "ClrValue" and "SetValue" methods are used for setting
**         the initial state.
**     Parameters  : None
**     Returns     :
**         ---             - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
**                           ERR_ENABLED - Bean is enabled. Bean must
**                           be disabled (see "Disable method")
** ===================================================================
*/
byte LCD_D4_SetValue(void)
{
  if (EnUser) {                        /* Is the device enabled by user? */
    return ERR_ENABLED;                /* If yes then error */
  }
  clrRegBits(PWMA_PMCFG,256);          /* Set output signal level to high */
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  LCD_D4_ClrValue (bean PWM)
**
**     Description :
**         This method clears (sets to "0" = "Low") timer flip-flop
**         output signal level. It allow user to directly set the
**         output pin value (=flip-flop state), and can set the
**         signal polarity. This method only works when the timer is
**         disabled (Disable) otherwise it returns the error code.
**         "ClrValue" and "SetValue" methods are used for setting
**         the initial state.
**     Parameters  : None
**     Returns     :
**         ---             - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
**                           ERR_ENABLED - Bean is enabled. Bean must
**                           be disabled (see "Disable method")
** ===================================================================
*/
byte LCD_D4_ClrValue(void)
{
  if (EnUser) {                        /* Is the device enabled by user? */
    return ERR_ENABLED;                /* If yes then error */
  }
  setRegBits(PWMA_PMCFG,256);          /* Set output signal level to low */
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  LCD_D4_Init (bean PWM)
**
**     Description :
**         Initializes the associated peripheral(s) and the beans 
**         internal variables. The method is called automatically as a 
**         part of the application initialization code.
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
void LCD_D4_Init(void)
{
  RatioStore = (word)32768U;           /* Store initial value of the ratio */
  EnUser = TRUE;                       /* Enable device */
  setReg(PWMA_PWMVAL0,10000);          /* Store initial value to the duty-compare register */
  SetPV((byte)2);                      /* Set prescaler register according to the selected high speed CPU mode */
}

/* END LCD_D4. */

/*
** ###################################################################
**
**     This file was created by UNIS Processor Expert 2.98.03 [03.79]
**     for the Freescale 56800 series of microcontrollers.
**
** ###################################################################
*/
