/** ###################################################################
**     THIS BEAN MODULE IS GENERATED BY THE TOOL. DO NOT MODIFY IT.
**     Filename  : TI2.C
**     Project   : pp
**     Processor : 56F801FA80
**     Beantype  : TimerInt
**     Version   : Bean 02.119, Driver 01.24, CPU db: 2.71.091
**     Compiler  : Metrowerks DSP C Compiler
**     Date/Time : 08/04/2008, 07:53 a.m.
**     Abstract  :
**         This bean "TimerInt" implements a periodic interrupt.
**         When the bean and its events are enabled, the "OnInterrupt"
**         event is called periodically with the period that you specify.
**         TimerInt supports also changing the period in runtime.
**         The source of periodic interrupt can be timer compare or reload
**         register or timer-overflow interrupt (of free running counter).
**     Settings  :
**         Timer name                  : TMRC1 (16-bit)
**         Compare name                : TMRC1_Compare
**         Counter shared              : No
**
**         High speed mode
**             Prescaler               : divide-by-1
**             Clock                   : 40000000 Hz
**           Initial period/frequency
**             Xtal ticks              : 2000
**             microseconds            : 250
**             seconds (real)          : 0.0002500
**             Hz                      : 4000
**             kHz                     : 4
**
**         Runtime setting             : none
**
**         Initialization:
**              Timer                  : Enabled
**              Events                 : Enabled
**
**         Timer registers
**              Counter                : TMRC1_CNTR [3405]
**              Mode                   : TMRC1_CTRL [3406]
**              Run                    : TMRC1_CTRL [3406]
**              Prescaler              : TMRC1_CTRL [3406]
**
**         Compare registers
**              Compare                : TMRC1_CMP1 [3400]
**
**         Flip-flop registers
**              Mode                   : TMRC1_SCR [3407]
**     Contents  :
**         Enable  - byte TI2_Enable(void);
**         Disable - byte TI2_Disable(void);
**
**     (c) Copyright UNIS, spol. s r.o. 1997-2006
**     UNIS, spol. s r.o.
**     Jundrovska 33
**     624 00 Brno
**     Czech Republic
**     http      : www.processorexpert.com
**     mail      : info@processorexpert.com
** ###################################################################*/

/* MODULE TI2. */

#include "Events.h"
#include "TI2.h"

static bool EnUser;                    /* Enable/Disable device by user */


/* Internal method prototypes */
static void HWEnDi(void);
static void SetCV(word Val);
static void SetPV(byte Val);

/*
** ===================================================================
**     Method      :  SetCV (bean TimerInt)
**
**     Description :
**         Sets compare or preload register value. The method is called 
**         automatically as a part of several internal methods.
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
static void SetCV(word Val)
{
  setReg(TMRC1_CMP1,Val);              /* Store given value to the compare register */
}

/*
** ===================================================================
**     Method      :  SetPV (bean TimerInt)
**
**     Description :
**         Sets prescaler value. The method is called automatically as a 
**         part of several internal methods.
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
static void SetPV(byte Val)
{
  setRegBitGroup(TMRC1_CTRL,PCS,Val);  /* Store given value to the prescaler */
  setReg(TMRC1_CNTR,0);                /* Reset counter */
}

/*
** ===================================================================
**     Method      :  HWEnDi (bean TimerInt)
**
**     Description :
**         Enables or disables the peripheral(s) associated with the bean.
**         The method is called automatically as a part of the Enable and 
**         Disable methods and several internal methods.
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
static void HWEnDi(void)
{
  if (EnUser) {                        /* Enable device? */
    setRegBitGroup(TMRC1_CTRL,CM,1);   /* Run counter */
  }
  else {                               /* Disable device? */
    setRegBitGroup(TMRC1_CTRL,CM,0);   /* Stop counter */
    setReg(TMRC1_CNTR,0);              /* Reset counter */
  }
}

/*
** ===================================================================
**     Method      :  TI2_Enable (bean TimerInt)
**
**     Description :
**         Enables the bean - it starts the timer. Events may be
**         generated ("DisableEvent"/"EnableEvent").
**     Parameters  : None
**     Returns     :
**         ---             - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
** ===================================================================
*/
byte TI2_Enable(void)
{
  if (!EnUser) {                       /* Is the device disabled by user? */
    EnUser = TRUE;                     /* If yes then set the flag "device enabled" */
    HWEnDi();                          /* Enable the device */
  }
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  TI2_Disable (bean TimerInt)
**
**     Description :
**         Disables the bean - it stops the timer. No events will be
**         generated.
**     Parameters  : None
**     Returns     :
**         ---             - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
** ===================================================================
*/
byte TI2_Disable(void)
{
  if (EnUser) {                        /* Is the device enabled by user? */
    EnUser = FALSE;                    /* If yes then set the flag "device disabled" */
    HWEnDi();                          /* Disable the device */
  }
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  TI2_Init (bean TimerInt)
**
**     Description :
**         Initializes the associated peripheral(s) and the beans 
**         internal variables. The method is called automatically as a 
**         part of the application initialization code.
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
void TI2_Init(void)
{
  /* TMRC1_CTRL: CM=0,PCS=0,SCS=0,ONCE=0,LENGTH=1,DIR=0,Co_INIT=0,OM=0 */
  setReg(TMRC1_CTRL,32);               /* Stop all functions of the timer */
  /* TMRC1_SCR: TCF=0,TCFIE=1,TOF=0,TOFIE=0,IEF=0,IEFIE=0,IPS=0,INPUT=0,Capture_Mode=0,MSTR=0,EEOF=0,VAL=0,FORCE=0,OPS=0,OEN=0 */
  setReg(TMRC1_SCR,16384);
  setReg(TMRC1_CNTR,0);                /* Reset counter register */
  setReg(TMRC1_LOAD,0);                /* Reset load register */
  EnUser = TRUE;                       /* Enable device */
  SetCV((word)9999);                   /* Store appropriate value to the compare register according to the selected high speed CPU mode */
  SetPV((byte)8);                      /* Set prescaler register according to the selected high speed CPU mode */
  HWEnDi();                            /* Enable/disable device according to status flags */
}

/*
** ===================================================================
**     Method      :  TI2_Interrupt (bean TimerInt)
**
**     Description :
**         The method services the interrupt of the selected peripheral(s)
**         and eventually invokes the beans event(s).
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
#pragma interrupt saveall
void TI2_Interrupt(void)
{
  clrRegBit(TMRC1_SCR,TCF);            /* Reset interrupt request flag */
  TI2_OnInterrupt();                   /* Invoke user event */
}

/* END TI2. */

/*
** ###################################################################
**
**     This file was created by UNIS Processor Expert 2.98.03 [03.79]
**     for the Freescale 56800 series of microcontrollers.
**
** ###################################################################
*/
