/*

			SAMESYS
		
			I2C ROUTINES
			
			Version:	0.91
			File:		I2C.H
		

*/



#define		I2CDELAY		5

#define		I2CEEPROM		0x00A0
#define		I2CRTC			0x00D0

#define	SDASet()			SDA_SetVal()
#define	SDAClr()			SDA_ClrVal()
#define	SCLSet()			SCL_SetVal()
#define	SCLClr()			SCL_ClrVal()
#define	SCKToggle()			SCL_NegVal()
#define	SCKSet()			SCL_SetVal()
#define	SDADirOut()			SDA_SetOutput()
#define	SDADirIn()			SDA_SetInput()

void i2cSend8Long(unsigned long data, unsigned int devid, unsigned int dir);
asm void i2cInit(void);
void i2cStartBit(void);
void i2cStopBit(void);
unsigned int i2cReceive8(unsigned int devid, unsigned int dir);
void i2cSendByte(unsigned char data, unsigned char devid, unsigned int dir);
//void i2cSendData(unsigned int data, unsigned int n);
void i2cTransmitByte(unsigned char data);
unsigned int i2cReceiveData(unsigned int n);
void i2cDelay(void);
unsigned int i2cAckBit(void);
void i2cStartBit2(void);
void i2cSendMultipleBytes(unsigned char *data, unsigned int nbytes, unsigned char devid, unsigned int dir);

#define	i2cBitDelay()		for(i=0;i<I2CDELAY;i++);
#define	i2cHalfBitDelay()	for(i=0;i<(I2CDELAY>>1);i++);
/*
#define	SDASet()			asm(bfset	#PINSDA,x:PORTI2C)
#define	SDAClr()			asm(bfclr	#PINSDA,x:PORTI2C)
#define	SCLSet()			asm(bfset	#PINSCK,x:PORTI2C)
#define	SCLClr()			asm(bfclr	#PINSCK,x:PORTI2C)
#define	SCKToggle()			asm(bfchg	#PINSCK,x:PORTI2C)
#define	SCKSet()			asm(bfset	#PINSCK,x:PORTI2C)
#define	SDADirOut()			asm(bfset	#PINSDA,x:DIRI2C)
#define	SDADirIn()			asm(bfclr	#PINSDA,x:DIRI2C)

asm void i2cInit(void)
{
	bfclr	#I2CPINS,x:I2CPORT_PER
	bfset	#I2CPINS,x:I2CPORT_PUR
	bfset	#I2CPINS,x:I2CPORT_DR
	bfset	#I2CPINS,x:I2CPORT_DDR
	bfset	#I2CPINS,x:I2CPORT_PUR
	
	bfchg	#I2CPINS,x:I2CPORT_DR
	bfchg	#I2CPINS,x:I2CPORT_DR
		
	rts
}
*/
void i2cDelay(void)
{
	unsigned int i;
	
	for(i=0;i<I2CDELAY;i++)
	{
		
	}
}

void i2cStartBit2(void)
{
	i2cDelay();
	SCLSet();
	i2cDelay();
	SDADirOut();
	SDAClr();					//	start bit
	i2cDelay();
	SCLClr();	
	SDADirIn();
}

void i2cStartBit(void)
{
	SDADirOut();
	//SCLSet();
	SDAClr();					//	start bit
	i2cDelay();
	SCLClr();	
	SDADirIn();
}

void i2cStopBit(void)
{
	SDADirOut();
	SDAClr();
	i2cDelay();
	SCLSet();
	i2cDelay();
	SDASet();					//	stop bit
	
	i2cDelay();					//	bus free time
}

unsigned int i2cAckBit(void)
{
	SDADirIn();
	i2cDelay();
	//asm(move.w	x:I2CPORT_DR,y0);
	SCLSet();
	//	read
	i2cDelay();
	SCLClr();
	return(SDA_GetVal());
}

void i2cTransmitByte(unsigned char data)
{
	unsigned int n;
	
	n = 8;
	do
	{
		if(data&0x0080)		//	byte version
			SDASet();
		else
			SDAClr();
		data <<= 1;
		SDADirOut();
		i2cDelay();
		SCLSet();
		i2cDelay();			//	publish
		SDADirIn();
		SCLClr();
	}while(--n);
}

unsigned int i2cReceiveData(unsigned int n)
{
	unsigned int data;
	
	SDADirIn();
	data = 0;
	n = 8;
	do
	{
		i2cDelay();
		data <<= 1;
		if(SDA_GetVal())
			data |= 0x0001;		//	byte mode
		SCLSet();
		i2cDelay();
		SCLClr();
	}while(--n);
	
	return(data);
}

unsigned int i2cReceive8(unsigned int devid, unsigned int dir)
{
	unsigned int k, data;
	
	i2cStartBit();
	i2cTransmitByte(devid);
	k = i2cAckBit();
	i2cTransmitByte(dir);
	k = i2cAckBit();
	
	i2cStartBit2();
	i2cTransmitByte(devid | 1);
	k = i2cAckBit();
	data = i2cReceiveData(8);
	k = i2cAckBit();
	i2cStopBit();
	
	return(data);
}

void i2cSendByte(unsigned char data, unsigned char devid, unsigned int dir)
{
	i2cStartBit();
	i2cTransmitByte(devid);
	i2cAckBit();
	i2cTransmitByte(dir);
	i2cAckBit();
	i2cTransmitByte(data);
	i2cAckBit();
	i2cStopBit();
}

void i2cSend8Long(unsigned long data, unsigned int devid, unsigned int dir)
{
	i2cSendByte((unsigned int)((data & 0xFF000000) >> 24), devid, dir + 0);
	i2cSendByte((unsigned int)((data & 0x00FF0000) >> 16), devid, dir + 1);
	i2cSendByte((unsigned int)((data & 0x0000FF00) >> 8), devid, dir + 2);
	i2cSendByte((unsigned int)((data & 0x000000FF) >> 0), devid, dir + 3);
}

void i2cSendMultipleBytes(unsigned char *data, unsigned int nbytes, unsigned char devid, unsigned int dir)
{
	unsigned int i;
	
	do
	{
		i2cSendByte(*(data++), devid, dir++);
		for(i=0;i<10000;i++){}
	}
	while(--nbytes);
}

/*		eof		*/
